"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DiscordInteractions = void 0;
const node_fetch_1 = require("node-fetch");
const utils_1 = require("./utils");
const DISCORD_ENDPOINT = "https://discord.com/api/v8/";
const makeEndpoint = (endpoint) => `${DISCORD_ENDPOINT}${endpoint}`;
class DiscordInteractions {
    constructor(opts) {
        this.verifySignature = (signature, timestamp, rawBody) => {
            return utils_1.verifySignature(this.publicKey, signature, timestamp, rawBody);
        };
        this.getApplicationCommands = () => {
            return node_fetch_1.default(makeEndpoint(`applications/${this.applicationid}/commands`), {
                headers: {
                    "Authorization": `${this.tokenPrefix}${this.authToken}`,
                },
            })
                .then((d) => d.json())
                .then((d) => d);
        };
        this.createApplicationCommand = (command) => {
            return node_fetch_1.default(makeEndpoint(`applications/${this.applicationid}/commands`), {
                method: "POST",
                body: JSON.stringify(command),
                headers: {
                    "Content-Type": "application/json",
                    "Authorization": `${this.tokenPrefix}${this.authToken}`,
                },
            })
                .then((d) => d.json())
                .then((d) => d);
        };
        this.editApplicationCommand = (commandId, command) => {
            return node_fetch_1.default(makeEndpoint(`applications/${this.applicationid}/commands/${commandId}`), {
                method: "POST",
                body: JSON.stringify(command),
                headers: {
                    "Content-Type": "application/json",
                    "Authorization": `${this.tokenPrefix}${this.authToken}`,
                },
            })
                .then((d) => d.json())
                .then((d) => d);
        };
        this.deleteApplicationCommand = (commandId) => {
            return node_fetch_1.default(makeEndpoint(`applications/${this.applicationid}/commands/${commandId}`), {
                method: "DELETE",
                headers: {
                    "Authorization": `${this.tokenPrefix}${this.authToken}`,
                },
            });
        };
        this.getGuildCommands = (guildId) => {
            return node_fetch_1.default(makeEndpoint(`applications/${this.applicationid}/guilds/${guildId}/commands`), {
                headers: {
                    "Authorization": `${this.tokenPrefix}${this.authToken}`,
                },
            })
                .then((d) => d.json())
                .then((d) => d);
        };
        this.createGuildCommand = (guildId, command) => {
            return node_fetch_1.default(makeEndpoint(`applications/${this.applicationid}/guilds/${guildId}/commands`), {
                method: "POST",
                body: JSON.stringify(command),
                headers: {
                    "Content-Type": "application/json",
                    "Authorization": `${this.tokenPrefix}${this.authToken}`,
                },
            })
                .then((d) => d.json())
                .then((d) => d);
        };
        this.editGuildCommand = (guildId, commandId, command) => {
            return node_fetch_1.default(makeEndpoint(`applications/${this.applicationid}/guilds/${guildId}/commands/${commandId}`), {
                method: "POST",
                body: JSON.stringify(command),
                headers: {
                    "Content-Type": "application/json",
                    "Authorization": `${this.tokenPrefix}${this.authToken}`,
                },
            })
                .then((d) => d.json())
                .then((d) => d);
        };
        this.deleteGuildCommand = (guildId, commandId) => {
            return node_fetch_1.default(makeEndpoint(`applications/${this.applicationid}/guilds/${guildId}/commands/${commandId}`), {
                method: "DELETE",
                headers: {
                    "Authorization": `${this.tokenPrefix}${this.authToken}`,
                },
            });
        };
        this.publicKey = opts.publicKey;
        this.applicationid = opts.applicationId;
        this.authToken = opts.authToken;
        this.tokenPrefix = (opts.tokenPrefix || "Bot") + " ";
    }
}
exports.DiscordInteractions = DiscordInteractions;
exports.default = DiscordInteractions;
